<?php
/* Copyright (C) 2007-2015 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2019      Open-DSI             <support@open-dsi.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *	    \file       htdocs/banking4dolibarr/admin/subscription.php
 *		\ingroup    banking4dolibarr
 *		\brief      Page to setup banking4dolibarr module
 */

// Change this following line to use the correct relative path (../, ../../, etc)
$res=0;
if (! $res && file_exists("../../main.inc.php")) $res=@include '../../main.inc.php';			// to work if your module directory is into a subdir of root htdocs directory
if (! $res && file_exists("../../../main.inc.php")) $res=@include '../../../main.inc.php';		// to work if your module directory is into a subdir of root htdocs directory
if (! $res) die("Include of main fails");
require_once DOL_DOCUMENT_ROOT . '/core/lib/admin.lib.php';
require_once DOL_DOCUMENT_ROOT . '/core/lib/date.lib.php';
require_once DOL_DOCUMENT_ROOT . '/core/class/html.formother.class.php';
require_once DOL_DOCUMENT_ROOT . '/core/class/html.formadmin.class.php';
dol_include_once('/banking4dolibarr/lib/banking4dolibarr.lib.php');
dol_include_once('/banking4dolibarr/class/module_key/opendsimodulekeyb4d.class.php');
dol_include_once('/banking4dolibarr/class/budgetinsight.class.php');
dol_include_once('/banking4dolibarr/class/html.formbanking4dolibarr.class.php');

$langs->load("admin");
$langs->load("banking4dolibarr@banking4dolibarr");
$langs->load("opendsi@banking4dolibarr");
$langs->load("oauth");

if (!$user->admin || empty($user->rights->banking4dolibarr->param_menu)) accessforbidden();

$action = GETPOST('action', 'aZ09');

$budgetinsight = new BudgetInsight($db);
$v17p = version_compare(DOL_VERSION, "17.0.0") >= 0;


/*
 *	Actions
 */
if (empty($budgetinsight->module_key) || $budgetinsight->module_key->b4d_entity == $conf->entity) {
	$errors = [];
	$error = 0;
	$db->begin();

	if ($action == 'set_api_options') {
		$value = GETPOST('BANKING4DOLIBARR_MODULE_KEY', 'alpha');
		if (!empty($value)) {
			$result = OpenDsiModuleKeyB4D::decode($value);
			if (!empty($result['error'])) {
				$errors[] = $result['error'];
				$error++;
			} else {
				$module_key_infos = $result['key'];

				// Check if the key is not already used in another entity
				$sql = "SELECT " . $db->decrypt('c.value') . " as value FROM " . MAIN_DB_PREFIX . "const AS c WHERE c.name = " .
					$db->encrypt('BANKING4DOLIBARR_MODULE_KEY', 1) .
					" AND c.entity NOT IN (" . getEntity('bank_account') . ")";
				$resql = $db->query($sql);
				if (!$resql) {
					$errors[] = $db->lasterror();
					$error++;
				} else {
					$replicate_key = false;
					while ($obj = $db->fetch_object($resql)) {
						if ($v17p) $value_tmp = dolDecrypt($obj->value);    // decrypt data excrypted with dolibarr_set_const($db, $name, $value)
						$result = OpenDsiModuleKeyB4D::decode($value_tmp);
						if (!empty($result['error'])) {
							$errors[] = $result['error'];
							$error++;
							break;
						} elseif ($result['key']->key == $module_key_infos->key) {
							$replicate_key = true;
							break;
						}
					}

					if ($replicate_key) {
						$errors[] = 'Replicate key on another entity';
						$error++;
					} else {
						$res = dolibarr_set_const($db, 'BANKING4DOLIBARR_MODULE_KEY', $value, 'chaine', 0, '', $conf->entity);
						if (!($res > 0)) {
							$errors[] = $db->lasterror();
							$error++;
						}
					}
				}
			}
		} else {
			$res = dolibarr_del_const($db, 'BANKING4DOLIBARR_MODULE_KEY', $conf->entity);
			if (!($res > 0)) {
				$errors[] = $db->lasterror();
				$error++;
			}
		}
	}
	$has_key = !empty($conf->global->BANKING4DOLIBARR_MODULE_KEY);

	if (!$error) {
		if ($action == 'set_api_options' && $has_key) {
			if (!$error) {
				$value = GETPOST('BANKING4DOLIBARR_API_TIMEOUT', 'int');
				$value = $value > 0 ? $value : 10;
				$res = dolibarr_set_const($db, 'BANKING4DOLIBARR_API_TIMEOUT', $value, 'chaine', 0, '', $conf->entity);
				if (!($res > 0)) {
					$errors[] = $db->lasterror();
					$error++;
				}

				$value = GETPOST('BANKING4DOLIBARR_REQUEST_LIMIT', 'int');
				$value = min(BudgetInsight::MAX_REQUEST_LIMIT, $value > 0 ? $value : BudgetInsight::DEFAULT_REQUEST_LIMIT);
				$res = dolibarr_set_const($db, 'BANKING4DOLIBARR_REQUEST_LIMIT', $value, 'chaine', 0, '', $conf->entity);
				if (!($res > 0)) {
					$errors[] = $db->lasterror();
					$error++;
				}
			}
		} elseif ($action == 'set_auto_create_link_bank_account' && $has_key) {
			$value = GETPOST('value', 'int');

			$res = dolibarr_set_const($db, 'BANKING4DOLIBARR_AUTO_LINK_BANK_ACCOUNT', $value == 1 || $value == 3 ? '1' : ($value == 0 ? '0' : $conf->global->BANKING4DOLIBARR_AUTO_LINK_BANK_ACCOUNT), 'chaine', 0, '', $conf->entity);
			if (!($res > 0)) {
				$errors[] = $db->lasterror();
				$error++;
			}

			$res = dolibarr_set_const($db, 'BANKING4DOLIBARR_AUTO_CREATE_BANK_ACCOUNT', $value == 3 ? '1' : ($value == 0 || $value == 2 ? '0' : $conf->global->BANKING4DOLIBARR_AUTO_CREATE_BANK_ACCOUNT), 'chaine', 0, '', $conf->entity);
			if (!($res > 0)) {
				$errors[] = $db->lasterror();
				$error++;
			}
		} elseif ($action == 'set_notify_options' && $has_key) {
			$value = GETPOST('BANKING4DOLIBARR_NOTIFY_EMAIL_REFRESH_BANK_RECORDS_USERS', 'array');
			$value = !empty($value) ? $value : array();
			$res = dolibarr_set_const($db, 'BANKING4DOLIBARR_NOTIFY_EMAIL_REFRESH_BANK_RECORDS_USERS', implode(',', $value), 'chaine', 0, '', $conf->entity);
			if (!($res > 0)) {
				$errors[] = $db->lasterror();
				$error++;
			}

			$value = GETPOST('BANKING4DOLIBARR_NOTIFY_EMAIL_REFRESH_BANK_RECORDS_GROUPS', 'array');
			$value = !empty($value) ? $value : array();
			$res = dolibarr_set_const($db, 'BANKING4DOLIBARR_NOTIFY_EMAIL_REFRESH_BANK_RECORDS_GROUPS', implode(',', $value), 'chaine', 0, '', $conf->entity);
			if (!($res > 0)) {
				$errors[] = $db->lasterror();
				$error++;
			}
		} elseif (preg_match('/set_(.*)/', $action, $reg)) {
			$code = $reg[1];
			$value = (GETPOST($code) ? GETPOST($code) : 1);
			$res = dolibarr_set_const($db, $code, $value, 'chaine', 0, '', $conf->entity);
			if ($res < 0) {
				$errors[] = $db->lasterror();
				$error++;
			}
		} elseif (preg_match('/del_(.*)/', $action, $reg)) {
			$code = $reg[1];
			$res = dolibarr_del_const($db, $code, $conf->entity);
			if ($res < 0) {
				$errors[] = $db->lasterror();
				$error++;
			}
		}
	}

	if ($action != '') {
		if (!$error) {
			$db->commit();
			setEventMessage($langs->trans("SetupSaved"));
			header("Location: " . $_SERVER["PHP_SELF"]);
			exit;
		} else {
			$db->rollback();
			setEventMessages('', $errors, 'errors');
		}
	}
}


/*
 *	View
 */

$form = new Form($db);
$formadmin = new FormAdmin($db);
$formother = new FormOther($db);
$formbanking4dolibarr = new FormBanking4Dolibarr($db);

$css_files = array(
    '/banking4dolibarr/css/banking4dolibarr.css.php'
);

$wikihelp = 'EN:Banking4Dolibarr_En|FR:Banking4Dolibarr_Fr|ES:Banking4Dolibarr_Es';
llxHeader('', $langs->trans("Banking4DolibarrSetup"), $wikihelp, '', 0, 0, array(), $css_files);

$linkback = '<a href="' . DOL_URL_ROOT . '/admin/modules.php">' . $langs->trans("BackToModuleList") . '</a>';
print load_fiche_titre($langs->trans("Banking4DolibarrSetup"), $linkback, 'title_setup');
print "<br>\n";

$head = banking4dolibarr_admin_prepare_head();

dol_fiche_head($head, 'subscription', $langs->trans("Module163036Name"), -1, 'opendsi@banking4dolibarr');

if (empty($budgetinsight->module_key) || $budgetinsight->module_key->b4d_entity == $conf->entity) {
	$disabled_message = $form->textwithpicto($langs->trans('Banking4DolibarrFunctionalityDisabled'), $langs->trans('Banking4DolibarrDisabledBecauseYouDontHaveKey'));

	/**
	 * API settings.
	 */

	print '<div id="api_options"></div>';
	print load_fiche_titre($langs->trans("Banking4DolibarrApiParameters"), '', '');
	print '<form method="post" action="' . $_SERVER["PHP_SELF"] . '#api_options">';
	print '<input type="hidden" name="token" value="' . newToken() . '">';
	print '<input type="hidden" name="action" value="set_api_options">';

	print '<table class="noborder" width="100%">';
	print '<tr class="liste_titre">';
	print '<td width="20%">' . $langs->trans("Parameters") . '</td>' . "\n";
	print '<td>' . $langs->trans("Description") . '</td>' . "\n";
	print '<td class="right">' . $langs->trans("Value") . '</td>' . "\n";
	print "</tr>\n";

	// Show redirect URI
	print '<tr class="oddeven">' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrRedirectUriName") . '</td>' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrRedirectUriDesc") . '</td>' . "\n";
	print '<td class="nowrap right">' . "\n";
	$redirect_uri = banking4dolibarr_url_host($_SERVER) . dol_buildpath('/banking4dolibarr/core/modules/oauth/webview_callback.php', 1);
	print '<input type="text" readonly="readonly" size="100" value="' . dol_escape_htmltag($redirect_uri) . '" />' . "\n";
	print '</td></tr>' . "\n";

	// BANKING4DOLIBARR_MODULE_KEY
	print '<tr class="oddeven">' . "\n";
	print '<td style="vertical-align: top;">' . $langs->trans("Banking4DolibarrModuleKeyName") . '</td>' . "\n";
	print '<td style="vertical-align: top;">' . $langs->trans("Banking4DolibarrModuleKeyDesc") . (empty($conf->global->BANKING4DOLIBARR_MODULE_KEY) ? $langs->trans("Banking4DolibarrModuleKeyPurchaseDesc") : '') . '</td>' . "\n";
	print '<td class="nowrap right">' . "\n";
	print '<textarea name="BANKING4DOLIBARR_MODULE_KEY" rows="10" cols="90">' . (!empty($conf->global->BANKING4DOLIBARR_MODULE_KEY) ? $conf->global->BANKING4DOLIBARR_MODULE_KEY : '') . '</textarea>' . "\n";
	print '</td></tr>' . "\n";

	// BANKING4DOLIBARR_DEBUG
	print '<tr class="oddeven">' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrDebugName") . '</td>' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrDebugDesc") . '</td>' . "\n";
	print '<td class="right">' . "\n";
	if ($has_key) {
		if (!empty($conf->use_javascript_ajax)) {
			print ajax_constantonoff('BANKING4DOLIBARR_DEBUG');
		} else {
			if (empty($conf->global->BANKING4DOLIBARR_DEBUG)) {
				print '<a href="' . $_SERVER['PHP_SELF'] . '?token=' . newToken() . '&action=set_BANKING4DOLIBARR_DEBUG#api_options">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
			} else {
				print '<a href="' . $_SERVER['PHP_SELF'] . '?token=' . newToken() . '&action=del_BANKING4DOLIBARR_DEBUG#api_options">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
			}
		}
	} else {
		print $disabled_message;
	}
	print '</td></tr>' . "\n";

	// BANKING4DOLIBARR_API_TIMEOUT
	print '<tr class="oddeven">' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrApiTimeOutName") . '</td>' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrApiTimeOutDesc") . '</td>' . "\n";
	print '<td class="nowrap right">' . "\n";
	if ($has_key) {
		print '<input type="number" name="BANKING4DOLIBARR_API_TIMEOUT" size="100" value="' . dol_escape_htmltag($conf->global->BANKING4DOLIBARR_API_TIMEOUT) . '" />' . "\n";
	} else {
		print $disabled_message;
	}
	print '</td></tr>' . "\n";

	// BANKING4DOLIBARR_REQUEST_LIMIT
	print '<tr class="oddeven">' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrRequestLimitName") . '</td>' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrRequestLimitDesc", BudgetInsight::DEFAULT_REQUEST_LIMIT, BudgetInsight::MAX_REQUEST_LIMIT) . '</td>' . "\n";
	print '<td class="nowrap right">' . "\n";
	if ($has_key) {
		print '<input type="number" name="BANKING4DOLIBARR_REQUEST_LIMIT" size="100" value="' . dol_escape_htmltag($conf->global->BANKING4DOLIBARR_REQUEST_LIMIT) . '" />' . "\n";
	} else {
		print $disabled_message;
	}
	print '</td></tr>' . "\n";


	print '</table>' . "\n";

	print '<br>';
	print '<div class="center">';
	print '<input type="submit" class="button" value="' . $langs->trans("Save") . '">';
	print '</div>';

	print '</form>';

	/**
	 * Bank account settings.
	 */

	print '<div id="bank_account_options"></div>';
	print load_fiche_titre($langs->trans("Banking4DolibarrBankAccountParameters"), '', '');
	print '<form method="post" action="' . $_SERVER["PHP_SELF"] . '#bank_account_options">';
	print '<input type="hidden" name="token" value="' . newToken() . '">';
	print '<input type="hidden" name="action" value="set_bank_account_options">';

	print '<table class="noborder centpercent">';
	print '<tr class="liste_titre">';
	print '<td width="20%">' . $langs->trans("Parameters") . '</td>' . "\n";
	print '<td>' . $langs->trans("Description") . '</td>' . "\n";
	print '<td class="right">' . $langs->trans("Value") . '</td>' . "\n";
	print "</tr>\n";

	// BANKING4DOLIBARR_AUTO_LINK_BANK_ACCOUNT
	print '<tr class="oddeven">' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrAutoLinkBankAccountName") . '</td>' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrAutoLinkBankAccountDesc") . '</td>' . "\n";
	print '<td class="right">' . "\n";
	if ($has_key) {
		if (empty($conf->global->BANKING4DOLIBARR_AUTO_LINK_BANK_ACCOUNT)) {
			print '<a href="' . $_SERVER['PHP_SELF'] . '?token=' . newToken() . '&action=set_auto_create_link_bank_account&value=1#bank_account_options">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
		} else {
			print '<a href="' . $_SERVER['PHP_SELF'] . '?token=' . newToken() . '&action=set_auto_create_link_bank_account&value=0#bank_account_options">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
		}
	} else {
		print $disabled_message;
	}
	print '</td></tr>' . "\n";

	// BANKING4DOLIBARR_AUTO_CREATE_BANK_ACCOUNT
	print '<tr class="oddeven">' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrAutoCreateBankAccountName") . '</td>' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrAutoCreateBankAccountDesc") . '</td>' . "\n";
	print '<td class="right">' . "\n";
	if ($has_key) {
		if (empty($budgetinsight->module_key->b4d_auto_link_bank_account)) {
			print '<a href="' . $_SERVER['PHP_SELF'] . '?token=' . newToken() . '&action=set_auto_create_link_bank_account&value=3#bank_account_options">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
		} else {
			print '<a href="' . $_SERVER['PHP_SELF'] . '?token=' . newToken() . '&action=set_auto_create_link_bank_account&value=2#bank_account_options">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
		}
	} else {
		print $disabled_message;
	}
	print '</td></tr>' . "\n";

	print '</form>';

	/**
	 * Notify settings.
	 */
	print '<div id="notify_options"></div>';
	print load_fiche_titre($langs->trans("Banking4DolibarrNotifyParameters"), '', '');
	print '<form method="post" action="' . $_SERVER["PHP_SELF"] . '#notify_options">';
	print '<input type="hidden" name="token" value="' . newToken() . '">';
	print '<input type="hidden" name="action" value="set_notify_options">';

	print '<table class="noborder centpercent">';
	print '<tr class="liste_titre">';
	print '<td width="20%">' . $langs->trans("Parameters") . '</td>' . "\n";
	print '<td>' . $langs->trans("Description") . '</td>' . "\n";
	print '<td class="right">' . $langs->trans("Value") . '</td>' . "\n";
	print "</tr>\n";

	// BANKING4DOLIBARR_NOTIFY_EMAIL_REFRESH_BANK_RECORDS
	print '<tr class="oddeven">' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrNotifyEmailRefreshBankRecordsName") . '</td>' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrNotifyEmailRefreshBankRecordsDesc") . '</td>' . "\n";
	print '<td class="nowrap right">' . "\n";
	if ($has_key) {
		if (empty($budgetinsight->module_key->b4d_notify_email_refresh_bank_records)) {
			print '<a href="' . $_SERVER['PHP_SELF'] . '?token=' . newToken() . '&action=set_BANKING4DOLIBARR_NOTIFY_EMAIL_REFRESH_BANK_RECORDS#notify_options">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
		} else {
			print '<a href="' . $_SERVER['PHP_SELF'] . '?token=' . newToken() . '&action=del_BANKING4DOLIBARR_NOTIFY_EMAIL_REFRESH_BANK_RECORDS#notify_options">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
		}
	} else {
		print $disabled_message;
	}
	print '</td></tr>' . "\n";

	// BANKING4DOLIBARR_NOTIFY_EMAIL_REFRESH_BANK_RECORDS_USERS
	print '<tr class="oddeven">' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrNotifyEmailRefreshBankRecordsUsersName") . '</td>' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrNotifyEmailRefreshBankRecordsUsersDesc") . '</td>' . "\n";
	print '<td class="nowrap right">' . "\n";
	if ($has_key) {
		print $formbanking4dolibarr->multiselect_dolusers($budgetinsight->module_key->b4d_notify_email_refresh_bank_records_users ?? [], 'BANKING4DOLIBARR_NOTIFY_EMAIL_REFRESH_BANK_RECORDS_USERS', '', empty($budgetinsight->module_key->b4d_notify_email_refresh_bank_records), '', array(), 0, 0, 0, 'AND fk_soc IS NULL', 0, '', '', 1);
	} else {
		print $disabled_message;
	}
	print '</td></tr>' . "\n";

	// BANKING4DOLIBARR_NOTIFY_EMAIL_REFRESH_BANK_RECORDS_GROUPS
	print '<tr class="oddeven">' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrNotifyEmailRefreshBankRecordsGroupsName") . '</td>' . "\n";
	print '<td>' . $langs->trans("Banking4DolibarrNotifyEmailRefreshBankRecordsGroupsDesc") . '</td>' . "\n";
	print '<td class="nowrap right">' . "\n";
	if ($has_key) {
		print $formbanking4dolibarr->multiselect_dolgroups($budgetinsight->module_key->b4d_notify_email_refresh_bank_records_groups ?? [], 'BANKING4DOLIBARR_NOTIFY_EMAIL_REFRESH_BANK_RECORDS_GROUPS', '', empty($budgetinsight->module_key->b4d_notify_email_refresh_bank_records), '', 1);
	} else {
		print $disabled_message;
	}
	print '</td></tr>' . "\n";

	print '</table>' . "\n";

	if ($has_key && !empty($budgetinsight->module_key->b4d_notify_email_refresh_bank_records)) {
		print '<br>';
		print '<div class="center">';
		print '<input type="submit" class="button" value="' . $langs->trans("Save") . '">';
		print '</div>';
	}

	print '</form>';
} else {
	$label = $budgetinsight->getEntityName($budgetinsight->module_key->b4d_entity);
	print info_admin($langs->trans('Banking4DolibarrConfigureOnEntity', $label));
}

dol_fiche_end();

llxFooter();

$db->close();
