<?php
/* Copyright (C) 2021 Open-DSI            <support@open-dsi.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * \file    htdocs/custom/banking4dolibarr/ajax/process_box.php
 * \brief   File to return Ajax response for start and watch a work with a process
 */
if (! defined('NOTOKENRENEWAL')) define('NOTOKENRENEWAL', 1); // Disables token renewal
if (! defined('NOREQUIREMENU')) define('NOREQUIREMENU', '1');
if (! defined('NOREQUIREHTML')) define('NOREQUIREHTML', '1');
if (! defined('NOREQUIREAJAX')) define('NOREQUIREAJAX', '1');
if (! defined('NOREQUIRESOC')) define('NOREQUIRESOC', '1');
if (! defined('NOCSRFCHECK')) define('NOCSRFCHECK', '1');
//if (! defined('NOREQUIRETRAN'))  define('NOREQUIRETRAN','1');

$res=0;
if (! $res && file_exists("../../main.inc.php")) $res=@include("../../main.inc.php");		// For root directory
if (! $res && file_exists("../../../main.inc.php")) $res=@include("../../../main.inc.php");	// For "custom" directory
dol_include_once('/banking4dolibarr/class/banking4dolibarrprocessbox.class.php', 'Banking4DolibarrProcessBox');

$id			= GETPOST('id', 'int');
$topic		= GETPOST('topic', 'aZ09');
$parameters	= GETPOST('parameters', 'array');
$start		= GETPOST('start', 'int');

$id = $id > 0 ? $id : 0;
$topic = trim($topic);
$parameters = is_array($parameters) ? $parameters : array();
$start = !empty($start) ? 1 : 0;

$langs->load('banking4dolibarr@banking4dolibarr');

$process_box = new Banking4DolibarrProcessBox($db);

$error = 0;
$processing = false;
$stopping = false;
$result = array();
$finished_page = "";

/*
 * View
 */

//$outjson = array(
//    'result' => '',           // Result text
//    'progressing' => false,   // if true then the process is working
//    'stopping' => false,  	// if true then the process is stopping
//);

try {
	if (!$error) {
		if (empty($id)) {
			$langs->load('errors');
			$result[] = $langs->trans('ErrorFieldRequired', $langs->transnoentitiesnoconv("TechnicalID"));
			$error++;
		}
		if (empty($topic)) {
			$langs->load('errors');
			$result[] = $langs->trans('ErrorFieldRequired', $langs->transnoentitiesnoconv("Banking4DolibarrTopic"));
			$error++;
		}
	}

	if (!$error) {
		$process_info = $process_box->getProcessInfo($id, $topic);
		$processing = $process_info['status'];
		$stopping = $process_info['stopping'];
		if (!$processing && $start) {
			// Start Process
			$res = $process_box->startProcess($id, $topic, $parameters);
			if ($res < 0) {
				$result[] = $process_box->errorsToString('<br>');
				$error++;
			} else {
				$start = 0;
				$process_info = $process_box->getProcessInfo($id, $topic, true);
				$processing = $process_info['status'];
				$stopping = $process_info['stopping'];
			}
		}

		// Get events messages
		$res = $process_box->getEventMessages($id, $topic);
		$result = array_merge($res, $result);

		if ($error || (!$processing && !$stopping)) {
			$process_box->clearEventMessages($id, $topic);
			$data_post_process = $process_box->getProcessPostData($id, $topic, true);
			if (!empty($data_post_process['finished_page'])) $finished_page = $data_post_process['finished_page'];
		}
	}
} catch (Exception $e) {
	$result[] = $e->getMessage();
}

echo json_encode(array(
	'start' => !$error && $start ? 1 : 0,
	'processing' => !$error && $processing,
	'stopping' => !$error && $stopping,
	'result' => implode('<br>', $result),
	'finished_page' => $finished_page,
));

$db->close();
