<?php
/*  Copyright (C) 2019      Open-DSI             <support@open-dsi.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *	\file       htdocs/custom/banking4dolibarr/class/html.formbanking4dolibarrprocessbox.class.php
 *  \ingroup    banking4dolibarr
 *	\brief      File of class with all html process box function for Banking4Dolibarr
 */

/**
 *	Class to manage generation of HTML components
 *	Only process box function for Banking4Dolibarr must be here.
 *
 */
class FormBanking4DolibarrProcessBox
{
    public $db;
    public $error;
    public $num;

	/**
	 * @var Form  Instance of the form
	 */
	public $form;

    /**
     * Constructor
     *
     * @param   DoliDB $db Database handler
     */
    public function __construct($db)
    {
    	global $form;

		$this->db = $db;
		$this->form = $form;
    	if (!is_object($this->form)) {
			require_once DOL_DOCUMENT_ROOT . '/core/class/html.form.class.php';
			$this->form = new Form($this->db);
		}
    }

	/**
	 *  Start process box management
	 *
	 * @param	string		$page        	   						Url of page to call if confirmation is OK
	 * @param  	string		$title	                				Title of the box.
	 * @param  	string		$title_already_started  				Title of the box if process already started.
	 * @param  	string		$text_already_started  					Additional text of the box if process already started.
	 * @param  	string		$question               				Question of the confirm box.
	 * @param  	string		$question_already_started				Question of the confirm box if process already started.
	 * @param  	string		$result_box_initial_text				Initial text of the result box.
	 * @param  	int			$id	            						Object ID
	 * @param  	string		$topic	                				Topic of the process.
	 * @param  	string		$parameters	            				Synchronization parameters
	 * @param  	string		$finished_page          				Url page to go when the box is closed.
	 * @param  	string		$form_id          						ID of the form to send when the box is closed.
	 * @param  	array		$additional_form_question				Additional form question of the confirm box.
	 * @param  	int			$confirm_box_height         			Height of confirm box
	 * @param	int			$confirm_box_width	       				Width of confirm box ('999' or '90%'). Ignored and forced to 95% on smartphones.
	 * @param  	int			$confirm_box_height_already_started		Height of confirm box if process already started.
	 * @param  	int			$confirm_box_width_already_started		Width of confirm box if process already started.
	 * @param  	int			$result_box_height         				Height of result box
	 * @param	int			$result_box_width	       				Width of result box ('999' or '90%'). Ignored and forced to 95% on smartphones.
	 * @param	int			$timeout	            				Ajax call every x milliseconds.
	 * @return 	string      	    	            				HTML AJAX code,
	 */
	function startProcessBox($page, $title, $title_already_started, $text_already_started, $question, $question_already_started, $result_box_initial_text, $id, $topic, $parameters, $finished_page = '', $form_id = '', $additional_form_question = array(), $confirm_box_height = 250, $confirm_box_width = 800, $confirm_box_height_already_started = 250, $confirm_box_width_already_started = 800, $result_box_height = 600, $result_box_width = 800, $timeout = 0)
	{
		global $action, $confirm, $process_box_topic, $langs;

		// Clean parameters
		$id = $id > 0 ? $id : 0;
		$topic = trim($topic);

		// Check parameters
		if (empty($title) || empty($id) || empty($topic) || empty($finished_page)) {
			$langs->load('errors');
			return $langs->trans('ErrorBadParameters');
		}

		if ($action != 'start_process_box' && $action != 'confirm_start_process_box' && $process_box_topic != 'auto_reconciliation') {
			return '';
		}

		dol_include_once('/banking4dolibarr/class/banking4dolibarrprocessbox.class.php', 'Banking4DolibarrProcessBox');
		$process_box = new Banking4DolibarrProcessBox($this->db);

		$b4d_token     = GETPOST('b4d_token', 'aZ09');
		$process_info = $process_box->getProcessInfo($id, $topic, true);
		$already_started = $process_info['status'] && !$process_info['stopping'];

		if ($action == 'start_process_box') {
			$form_question = array();
			if ($already_started) {
				$title = $title_already_started;
				$question = $question_already_started;
				$confirm_box_height = 30 + $confirm_box_height_already_started;
				$confirm_box_width = $confirm_box_width_already_started;
				$form_question = array_merge($form_question, array('text' => '<span style="color: red">' . $text_already_started . $langs->trans('Banking4DolibarrErrorProcessStartedSince', dol_print_date($process_info['started_at'], 'dayhour')) . '</span>'));
			}
			if (is_array($additional_form_question)) $form_question = array_merge($form_question, $additional_form_question);

			$_SESSION['b4d_token'] = uniqid('', true);
			$formconfirm = $this->form->formconfirm($page . (strpos($page, '?') === false ? '?' : '&') . 'process_box_topic=' . urlencode($topic) . "&b4d_token=" . $_SESSION['b4d_token'],
				$title, $question, 'confirm_start_process_box', $form_question, 'no', 2, $confirm_box_height, $confirm_box_width);
		} elseif (isset($_SESSION['b4d_token']) && $_SESSION['b4d_token'] == $b4d_token) {
			unset($_SESSION['b4d_token']);
			$show_box = false;
			$start = 1;
			if ($already_started) {
				if ($confirm == 'yes') { // stop current process
					$process_box->stopProcess($id, $topic);
				} else {
					// Don't restart the process
					$start = 0;
				}
				$show_box = true;
			} elseif ($confirm == 'yes') {
				$show_box = true;
			}

			$formconfirm = '';
			if ($show_box) {
				$formconfirm = $this->processBox($title, $id, $topic, $parameters, $result_box_initial_text, $start, $finished_page, $form_id, $result_box_height, $result_box_width, $timeout);
			}
		}

		return $formconfirm;
	}

	/**
	 *  HTML of the box for the process in AJAX
	 *
	 * @param  	string		$title	      		Title of the box.
	 * @param  	int			$id	          		Object ID
	 * @param  	string		$topic	      		Topic of the process.
	 * @param  	string		$parameters	  		Synchronization parameters
	 * @param  	string		$initial_text		Initial text of the box.
	 * @param  	int			$start        		Start the process
	 * @param  	string		$finished_page		Url page to go when the box is closed.
	 * @param  	string		$form_id      		ID of the form to send when the box is closed.
	 * @param  	int			$height       		Force height of box
	 * @param	int			$width	      		Force width of box ('999' or '90%'). Ignored and forced to 95% on smartphones.
	 * @param	int			$timeout	  		Ajax call every x milliseconds.
	 * @return 	string      	    	  		HTML AJAX code,
	 */
	function processBox($title, $id, $topic, $parameters, $initial_text = '', $start = 0, $finished_page = '', $form_id = '', $height = 600, $width = 800, $timeout = 0)
	{
		global $langs, $conf;

		$title = dol_escape_js(dol_escape_htmltag($title), 2);
		$id = $id > 0 ? $id : 0;
		$topic = trim($topic);
		$initial_text = trim($initial_text);
		$finished_page = trim($finished_page);
		$finished_page = dol_escape_js($finished_page, 2);

		if (empty($title) || empty($id) || empty($topic) || empty($finished_page)) {
			$langs->load('errors');
			return $langs->trans('ErrorBadParameters');
		}

		$parameters = is_array($parameters) ? $parameters : array();
		if (!empty($initial_text)) $parameters['process_box_initial_text'] = $initial_text;
		$form_id = trim($form_id);
		$form_id = dol_escape_js($form_id, 2);
		$width = preg_match('/^(\d+)$/', $width, $matches) && $matches[1] > 0 ? $width : 800;
		$height = preg_match('/^(\d+)$/', $height, $matches) && $matches[1] > 0 ? $height : 600;
		if ($conf->browser->layout == 'phone') $width = '95%';
		$timeout = $timeout > 0 ? $timeout : (!empty($conf->global->BANKING4DOLIBARR_REFRESH_TIMEOUT_AUTO_RECONCILIATION_BOX) && $conf->global->BANKING4DOLIBARR_REFRESH_TIMEOUT_AUTO_RECONCILIATION_BOX > 0 ? $conf->global->BANKING4DOLIBARR_REFRESH_TIMEOUT_AUTO_RECONCILIATION_BOX : 5000);

		$ajax_url = dol_escape_js(dol_buildpath('/banking4dolibarr/ajax/process_box.php', 1), 2);
		$close_button_text = dol_escape_js($langs->transnoentitiesnoconv('Banking4DolibarrClose'), 2);
		$wait_text = $langs->trans('Banking4DolibarrPleaseWait');
		$wait_text_escaped = dol_escape_js($wait_text, 2);
		$stopping_text = $langs->trans('Banking4DolibarrProcessStopping');
		$finished_text = $langs->trans('Banking4DolibarrProcessFinished');
		$class_fonts_awesome = !empty($conf->global->EASYA_VERSION) && version_compare(DOL_VERSION, "10.0.0") >= 0 ? 'fal' : 'fa';

		$ajax_data = json_encode(array(
			'id' => $id,
			'topic' => $topic,
			'parameters' => $parameters,
			'start' => $start,
            'token' => currentToken(),
		));

		// Show JQuery process box.
		$process_box = <<<SCRIPT
    <div id="b4d_process_box" title="$title" style="display: none;">
		<div id="b4d_process_box_content">$initial_text</div>
		<div id="b4d_process_box_wait"><span class="$class_fonts_awesome fa-spinner fa-spin"></span> $wait_text</div>
		<div id="b4d_process_box_stop"><span class="$class_fonts_awesome fa-spinner fa-spin"></span> $stopping_text</div>
		<div id="b4d_process_box_finish">$finished_text</div>
    </div>
    <script type="text/javascript">
        jQuery(document).ready(function() {
            var b4d_process_box = $("#b4d_process_box");
            var b4d_process_box_content = $("#b4d_process_box_content");
            var b4d_process_box_wait = $("#b4d_process_box_wait");
            var b4d_process_box_stop = $("#b4d_process_box_stop");
            var b4d_process_box_finish = $("#b4d_process_box_finish");
            b4d_process_box.attr('finished_page', "$finished_page");
            b4d_process_box.dialog({
                autoOpen: true,
    			open: function() {
					let close_button = $('button.ui-button:contains("{$close_button_text}")');
					close_button.addClass('b4d_close_button');
					close_button.prop('disabled', true);
					close_button.html('<span class="{$class_fonts_awesome} fa-spinner fa-spin"></span> {$wait_text_escaped}');
                    b4d_show_set_process_box_text_status(false, false, false);
                    b4d_launch_process_process($ajax_data);
                },
    			close: function() {
                    b4d_close_process_box();
                },
                resizable: false,
                height: "$height",
                width: "$width",
                modal: true,
                closeOnEscape: false,
                buttons: {
                    "$close_button_text": function() {
                        $(this).dialog("close");
                    }
                }
            });
            function b4d_close_process_box() {
                var finished_page = b4d_process_box.attr('finished_page');
				b4d_blockui();
                if (finished_page.length > 0) {
                    window.location.replace(finished_page);
                } else {
                    var form_id = "$form_id";
                    if (form_id.length == 0) {
                        document.location.reload(true);
                    } else {
                        $("#" + form_id).submit();
                    }
                }
            }
            function b4d_blockui() {
				if (typeof jQuery.blockUI != "undefined") {
					console.log("BlockUI set");
					jQuery.blockUI({message:  '<h1><span class="$class_fonts_awesome fa-spinner fa-spin"></span> {$wait_text_escaped}</h1>'});;
				} else {
					console.warn("BlockUI not found!");
				}
            }
            function b4d_set_process_box_text(text) {
            	if (text.length == 0) text = "$initial_text";
				b4d_process_box_content.html(text);
            }
            function b4d_set_bottom_position_process_box_text() {
				b4d_process_box.scrollTop(b4d_process_box.prop("scrollHeight"));
            }
            function b4d_show_set_process_box_text_status(waiting, stopping, finished) {
            	if (waiting) {
            		b4d_process_box_wait.show();
            	} else {
            		b4d_process_box_wait.hide();
            	}
            	if (stopping) {
            		b4d_process_box_stop.show();
            	} else {
            		b4d_process_box_stop.hide();
            	}
            	if (finished) {
            		b4d_process_box_finish.show();
            	} else {
            		b4d_process_box_finish.hide();
            	}
            }
            function b4d_unblock_button() {
				let close_button = $('button.b4d_close_button');
				close_button.prop('disabled', false);
				close_button.html('{$close_button_text}');
            }
            function b4d_launch_process_process(data) {
                $.ajax("$ajax_url", {
                    method: "POST",
                    data: data,
                    dataType: "json"
                }).done(function(response) {
                    if (typeof response === 'undefined' || response === null) {
						b4d_unblock_button();
                        b4d_set_process_box_text('Error empty response');
                    } else {
                		var data = $ajax_data;
	             		data.start = typeof response.start !== 'undefined' ? response.start : 0;

                    	if (typeof response.result === 'string') {
                    		b4d_set_process_box_text(response.result);
                    	}
                    	if (typeof response.finished_page === 'string' && response.finished_page.length > 0) {
           					b4d_process_box.attr('finished_page', response.finished_page);
                    	}
                    	if (typeof response.stopping !== 'undefined' && response.stopping) {
                    		b4d_show_set_process_box_text_status(false, true, false);
                    		setTimeout(b4d_launch_process_process, $timeout, data);
                    	} else if (typeof response.processing !== 'undefined' && response.processing) {
                            b4d_show_set_process_box_text_status(true, false, false);
       						setTimeout(b4d_launch_process_process, $timeout, data);
                    	} else {
							b4d_unblock_button();
                            b4d_show_set_process_box_text_status(false, false, true);
                    	}
						b4d_set_bottom_position_process_box_text();
                    }
                }).fail(function(jqxhr, textStatus, error) {
                    b4d_set_process_box_text(textStatus + " - " + error);
                    b4d_show_set_process_box_text_status(false, false);
					b4d_unblock_button();
					b4d_set_bottom_position_process_box_text();
                });
            }
        });
    </script>
SCRIPT;

		return $process_box;
	}
}

